@@ -4,7 +4,7 @@
 !    are filtered. this removes the time step restriction due to
 !    convergence of meridians.
 
-#if defined fourfil || defined firfil
+#if defined O_fourfil || defined O_firfil
 !    istf  = starting index for filtering "t" grid points
 !    ietf  = ending index for filtering "t" grid points
 !    isuf  = starting index for filtering "u,v" grid points
@@ -39,7 +39,7 @@
 
       common /index_i/ jfrst, jft0, jft1, jft2, jfu0, jfu1, jfu2
       common /index_i/ jskpt, jskpu, njtbft, njtbfu
-# if defined firfil
+# if defined O_firfil
       common /index_i/ numflt(jmtfil), numflu(jmtfil)
 # endif
       common /index_i/ istf(jmtfil,lsegf,km), ietf(jmtfil,lsegf,km)
