@@ -33,4 +33,10 @@
       common /scalar_r/ rho0, rho0r, omega, radius, grav, cdbot, gcor
       common /scalar_r/ taux0, tauy0
 
-#include "ndcon.h"
+!     various non dimensional quantities:
+
+!     radian = degrees per radian
+!     pi     = something good to eat
+
+      real radian, pi
+      common /ndcon/ radian, pi
