@@ -14,7 +14,7 @@
 !       (9) = change due to explicit convection
 !      (10) = change due to filtering
 !      (11) = average tracer within volume (tracer units)
-#if defined uvic_tbt
+#if defined O_mom_tbt
 
       integer ntbtts
       common /tbt_i/ ntbtts
